.. _contributing:

===================================
Contributing to python-openstacksdk
===================================

If you're interested in contributing to the python-openstacksdk project,
the following will help get you started.

Contributor License Agreement
-----------------------------

.. index::
   single: license; agreement

In order to contribute to the python-openstacksdk project, you need to have
signed OpenStack's contributor's agreement.

Please read `DeveloperWorkflow`_ before sending your first patch for review.
Pull requests submitted through GitHub will be ignored.

.. seealso::

   * http://wiki.openstack.org/HowToContribute
   * http://wiki.openstack.org/CLA

.. _DeveloperWorkflow: http://docs.openstack.org/infra/manual/developers.html#development-workflow

Project Hosting Details
-------------------------

Project Documentation
    http://docs.openstack.org/sdks/python/openstacksdk/

Bug tracker
    https://bugs.launchpad.net/python-openstacksdk

Mailing list (prefix subjects with ``[sdk]`` for faster responses)
    http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev

Code Hosting
    https://git.openstack.org/cgit/openstack/python-openstacksdk

Code Review
    https://review.openstack.org/#/q/status:open+project:openstack/python-openstacksdk,n,z
